@@ -4,7 +4,6 @@ use reqwest::header;
 
 /// Method to get max-age from reqwest::Response
 pub fn get_max_age(response: &reqwest::Response) -> Option<Duration> {
-    println!("qqq");
     let headers = response.headers();
     let cache_control = headers.get(header::CACHE_CONTROL)?;
     let cache_control = cache_control.to_str().ok()?;
@@ -21,7 +20,5 @@ pub fn get_max_age(response: &reqwest::Response) -> Option<Duration> {
 
     let max_age = max_age.parse::<u64>().ok()?;
 
-    println!("rrr: {}", max_age);
-
     Some(Duration::from_secs(max_age))
 }
